<template>
    <div class="full-page bg" element-loading-text="数据加载中..." element-loading-spinner="el-icon-loading"
        element-loading-background="rgba(255,255,255, 0.5)" v-loading.fullscreen.lock="markLoading">
        <div class="search-container">
            <el-form ref="form" :model="searchForm" label-width="auto" style="width: 100%">
                <el-row :gutter="20">
                    <el-col :span="5">
                        <el-form-item label="项目名称">
                            <el-input v-model="queryParam.querys[0].value" clearable placeholder="请输入项目名称">
                            </el-input>
                        </el-form-item>
                    </el-col>
                    <el-col :span="5">
                        <el-form-item label="项目分类">
                            <dict-select dictCode="sgyp-xmfl" :hasDefaultOption="true" clearable
                                v-model="queryParam.querys[3].value" style="width: 100%" placeholder="请选择项目分类" />
                        </el-form-item>
                    </el-col>
                    <el-col :span="5">
                        <el-form-item label="专项小组">
                            <dict-select dictCode="zxxz" v-model="queryParam.querys[1].value" :hasDefaultOption="true"
                                clearable style="width: 100%" placeholder="请选择专项小组" />
                        </el-form-item>
                    </el-col>
                    <el-col :span="2">
                        <el-button icon="el-icon-search" type="primary" class="btn btn-plus" @click="handleSearch(1)">
                            搜索
                        </el-button>
                    </el-col>
                </el-row>
            </el-form>
        </div>
        <el-row :gutter="10" class="main-table-container flex">
            <el-col :span="24" class="table-container" ref="contentPanel" style="padding: 20px">
                <div ref="btnPanel"></div>
                <div :style="{ width: '100%', height: `${tableMaxHeight}` + 'px' }">
                    <el-table stripe size="mini" v-loading="loading" ref="multipleSelection" :data="tableData"
                        :max-height="tableMaxHeight" :style="{ width: '100%' }">
                        <el-table-column label="序号" type="index" width="60" align="center"></el-table-column>
                        <el-table-column prop="projectName" min-width="220" show-overflow-tooltip label="项目名称" align="center">
                        </el-table-column>
                        <el-table-column prop="projectName" show-overflow-tooltip label="项目类型" align="center">
                            <template v-slot="{ row }">
                                {{ getDictName('xmlx', row.projectType) }}
                            </template>
                        </el-table-column>
                        <el-table-column prop="groupName" min-width="120" show-overflow-tooltip label="专项小组" align="center">
                        </el-table-column>
                        <el-table-column prop="unitName" min-width="100" show-overflow-tooltip label="主责单位" align="center">
                        </el-table-column>
                        <el-table-column prop="createTime" min-width="120" show-overflow-tooltip label="填报时间" align="center">
                        </el-table-column>
                        <el-table-column prop="progressStatusText" width="100" show-overflow-tooltip label="填报状态" align="center">
                            <template v-slot="{ row }">
                                <el-tag :type="row.progressStatus > 1 ? 'success' : row.progressStatus ==0 ? 'info' : ''">
                                    {{ row.progressStatusText || '未填报审批' }}
                                </el-tag>
                            </template>
                        </el-table-column>
                        <el-table-column show-overflow-tooltip align="center" fixed="right" width="100" label="操作">
                            <template v-slot="{ row }">
                                <template>
                                    <el-link icon="el-icon-s-check" type="primary" @click="advanceReport(row)"
                                        :underline="false" class="cloumn-btn">
                                        上报
                                    </el-link>
                                </template>
                            </template>
                        </el-table-column>
                    </el-table>
                </div>
                <pagination ref="paginationPanel" style="margin-top: 10px" :pageResult="queryParam.pageBean"
                    @size-change="handleSizeChange" @current-change="handleCurrentChange" />
            </el-col>
        </el-row>
        <TwoMonthReport ref="TwoMonthReport" @refreshData="getData"></TwoMonthReport>
    </div>
</template>

<script>
import pagination from '@/components/pagination'
import { TableMixin } from '@/mixins/tableMixin'
import utils from '@/utils.js'
import apiList from '@/api/MajorReformProjects/monthReport.js'
import TwoMonthReport from '../TwoMonthReport.vue'
export default {
    name: 'ReserveTwoMonthReport',
    components: {
        pagination,
        TwoMonthReport,
    },
    mixins: [TableMixin],
    data() {
        return {
            markLoading: false,
            searchForm: {},
            loading: false,
            tableData: [],
            multipleSelection: [],
            queryParam: {
                pageBean: {
                    page: 1,
                    pageSize: 20,
                    total: 0,
                },
                querys: [
                    {
                        group: 'main',
                        operation: 'LIKE',
                        parentGroup: '',
                        property: 'project_name_',
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'LIKE',
                        parentGroup: '',
                        property: 'group_Name_',
                        relation: 'AND',
                        value: '',
                    },
                    {
                        group: 'main',
                        operation: 'LIKE',
                        parentGroup: '',
                        property: 'm.project_type_',
                        relation: 'AND',
                        value: '3',
                    },
                    {
                        group: 'main',
                        operation: 'LIKE',
                        property: 'project_Category_',
                        relation: 'AND',
                        value: ''
                    },
                ],
            },
        }
    },
    created() {
        this.getData()
    },
    mounted() { 
        this.$bus.$on('dataRefresh', () => {
            this.getData()
        })
    },
    methods: {
        //获取数据
        getData() {
            this.loading = true
            this.tableData = []
            apiList.twoBatchProject(this.queryParam, false).then((res) => {
                if (res.rows) {
                    this.tableData = res.rows
                    this.queryParam.pageBean.page = res.page
                    this.queryParam.pageBean.total = res.total
                    // this.$set(this.tableData)
                    this.loading = false
                }
            })
        },
        // 推进更新
        advanceReport(data) {
            // '1' 加快实施一批
            this.$refs.TwoMonthReport.openDialog('两月进度上报', data, '2')
        },
        getDictName(code, value) {
            return utils.getDictName(code, value)
        },
        handleSearch(page) {
            if (page) {
                this.queryParam.pageBean.page = page
            }
            this.getData()
        },

        //展示数量
        handleSizeChange(val) {
            this.queryParam.pageBean.pageSize = val
            this.handleSearch(1)
        },
        //表格页数
        handleCurrentChange(val) {
            this.queryParam.pageBean.page = val
            this.handleSearch(val)
        },
    },
}
</script>

<style lang="scss" scoped>
.common-tree-container {
    height: calc(100% - 70px);
    margin-top: 0.52083vw;
    padding: 1.04167vw 1.04167vw;
    background-color: #fff;
    position: relative;
    box-sizing: border-box;
    overflow-y: auto;
    border-radius: 20px;
    box-shadow: 0px 0px 0.625vw 0 rgba(92, 102, 83, 0.2);
}

.container-head {
    display: flex;
    align-items: center;

    i {
        font-size: 16px;
        margin-left: 5px;
        font-weight: 600;
        cursor: pointer;
    }
}

.del-btn {
    border: 1px solid #f56c6c;
    padding: 3px 10px;
    border-radius: 5px;
    margin-right: 5px;

    &:hover {
        background-color: #f56c6c;
        color: #fff;
    }
}

.cloumn-btn {
    border: 1px solid #2761ff;
    padding: 3px 10px;
    border-radius: 5px;
    margin-right: 5px;

    &:hover {
        background-color: #2761ff;
        color: #fff;
    }

    /deep/ i,
    span {
        font-size: 16px;
    }
}
</style>
